flash(1M)

flash - reprogram the flash PROM hardware on Origin and OCTANE machines

As shipped in IRIX 6.5.19. Last changed in IRIX 6.5.15.

NAME
     flash - reprogram the flash PROM hardware on Origin and OCTANE machines

SYNOPSIS
     flash [ -a ] [ -c ] [ -d ] [ -D ] [ -f ] [ -F ] [ -i ] [ -m module_id ]
          [ -n ] [ -o ] [ -p dir_name ] [ -P img_name ] [ -s slot_name ] [ -S ]
          [ -v ] [ -V ]

     The SGI Origin 3000 server series.
     flash [ -a ] [ -d ] [ -D ] [ -f ] [ -F ] [ -b brick_id ]
           [ -o ] [ -p dir_name ] [ -P img_name ] [ -S ]
           [ -v ] [ -V ]

     flash -L

DESCRIPTION
     flash allows a user to manage the flash PROMs on the IO and CPU boards of
     Origin systems, the base system board on OCTANE systems and CPU boards on
     the SGI Origin 3000 server series.  Without options, the command flashes
     all appropriate boards on the machine with the PROM images found in
     /usr/cpu/firmware.  Normally, flash is executed automatically during the
     installation of a new release of IRIX.  A customer should rarely need to
     use it directly.  You must have superuser privilege to use this command.

     By default on Origin systems, flash takes the current configuration
     values (such as processor speed and cache size) that are currently stored
     in the CPU board PROM and uses these values when flashing the new images.
     Without options, flash proceeds in parallel in two phases.  Half the
     boards are flashed in the first phase and half in the second.  Using
     options, it is possible to flash a subset of the boards.  Also, the user
     can specify a different image directory and different image files.

     By default on OCTANE systems, the single system flash PROM is flashed
     with the specified image.  On OCTANE systems, options specifying multiple
     PROMs, types of PROMs, or PROM configuration values will be silently
     ignored.

     OCTANE systems have an additional feature of storing information from
     diagnostics in the flash PROM for extraction at a later time.  The -L
     option invokes this processing, and transfers the extracted information
     into syslog.  This processing will take place automatically during each
     system boot.

     Unless forced, flash does not flash the PROM unless the specified version
     is newer than what is currently in the PROM.  flash can also be used to
     obtain information about the current PROMs.

     The options are:

     -a           Flash all PROMs at once, overriding the protection of
                  flashing in two groups.
     -c           Flash only the node (CPU) PROMs on the machine.  This option
                  is ignored on the SGI Origin 3000 server series.

     -d           Print out the PROM header information for the current PROMs.

     -D           Dump the entire contents of a PROM to a file.

     -f           Specify different (than currently in PROM) configurations
                  values to be used when the new images are flashed.  These
                  values include the speed of the CPU, hub, and size of the
                  cache.  This option should be used with great care as cause
                  the machine to freeze and be rendered unusable if incorrect
                  values are given.

     -F           Similar to -f except more detailed information is required
                  and no checking is done in the input values.  This is more
                  dangerous the -f option and the same cautions apply.

     -i           Flash only the IO PROMs on the machine.  This option is
                  ignored on the SGI Origin 3000 server series.

     -m module_id Flash only PROMs in the module given by module_id.  This
                  option does not apply to the SGI Origin 3000 server series.

     -b brick_id  Flash only PROMs in the brick given by brick_id.  This
                  option applies only to the SGI Origin 3000 server series.

     -n           Flash only the node (CPU) PROMs on the machine. This option
                  is ignored on the SGI Origin 3000 server series.

     -o           Override the version checking and flash the PROM even if it
                  is not newer than what is currently on the PROM.

     -p dir_name  Specify a directory other than the default of
                  /usr/cpu/firmware to look for images.  Note that there are
                  standard names that flash looks for and thus the files in
                  this should follow the correct naming scheme.

     -P img_name  Specify the full pathname of the image desired to be
                  flashed.  The options specifying the type of PROM to be
                  flashed should match the PROM specified in img_name.

     -s slot_name Flash only the PROMs in the slot given by slot_name.  This
                  option does not apply to the SGI Origin 3000 server series.

     -S           Force all the flashes to occur sequentially (versus in two
                  parallel phases).

     -v           Turn on verbose mode.

     -V           Print currently loaded flash PROM version and time flashed
                  information.

     OCTANE specific options

     -L           Extract information logged into the flash PROM by
                  diagnostics from the PROM and into syslog.

FILES
     /usr/cpu/firmware/io6prom.img      default file for flashing IO PROMs for
                                        Origin
     /usr/cpu/firmware/ip27prom.img     default file for flashing CPU PROMs
                                        for Origin 2000 and Origin 200
     /usr/cpu/firmware/ip35prom.img     default file for flashing CPU PROMs
                                        for Origin 3000
     /usr/cpu/firmware/IP30prom.bin     default file for flashing OCTANE PROMs

WARNINGS
     The flash command is not intended for casual use.  If used incorrectly,
     it can completely freeze a system and prevent it from even booting the
     PROM.  Also, frequent flashing decreases the lifetime of the system's
     boards.  Silicon Graphics strongly recommends that this command only be
     used under the supervision of a support representative.